
__version__ = "4.5"
docs = r"https://crocodile.readthedocs.io/en/latest/"
git = r"https://github.com/thisismygitrepo/crocodile"
release_notes = """

Added Log and Frdige classes.
"""
